@@ -2,8 +2,7 @@
 from __future__ import annotations
 import sys
 
-from io import StringIO
-
+from typing import List
 from typing import Optional
 from typing import TextIO
 from typing import TYPE_CHECKING
@@ -11,6 +10,7 @@ from typing import TYPE_CHECKING
 from liquid.token import Token
 from liquid.token import TOKEN_TAG
 
+from liquid.ast import ChildNode
 from liquid.ast import Node
 from liquid.ast import BlockNode
 
@@ -28,7 +28,7 @@ if TYPE_CHECKING:  # pragma: no cover
 TAG_IFCHANGED = sys.intern("ifchanged")
 TAG_ENDIFCHANGED = sys.intern("endifchanged")
 
-ENDIFCHANGEDBLOCK = (TAG_ENDIFCHANGED,)
+ENDIFCHANGEDBLOCK = frozenset((TAG_ENDIFCHANGED,))
 
 
 class IfChangedNode(Node):
@@ -48,7 +48,7 @@ class IfChangedNode(Node):
 
     def render_to_output(self, context: Context, buffer: TextIO) -> Optional[bool]:
         # Render to an intermediate buffer.
-        buf = StringIO()
+        buf = context.get_buffer(buffer)
         self.block.render(context, buf)
         val = buf.getvalue()
 
@@ -62,7 +62,7 @@ class IfChangedNode(Node):
         self, context: Context, buffer: TextIO
     ) -> Optional[bool]:
         # Render to an intermediate buffer.
-        buf = StringIO()
+        buf = context.get_buffer(buffer)
         await self.block.render_async(context, buf)
         val = buf.getvalue()
 
@@ -72,6 +72,9 @@ class IfChangedNode(Node):
             return True
         return False
 
+    def children(self) -> List[ChildNode]:
+        return self.block.children()
+
 
 class IfChangedTag(Tag):
     """The built-in "ifchanged" tag"""
